pub enum IkeV2PayloadContent<'a> {
SA(Vec<IkeV2Proposal<'a>>),
KE(KeyExchangePayload<'a>),
IDi(IdentificationPayload<'a>),
IDr(IdentificationPayload<'a>),
Certificate(CertificatePayload<'a>),
CertificateRequest(CertificateRequestPayload<'a>),
Authentication(AuthenticationPayload<'a>),
Nonce(NoncePayload<'a>),
Notify(NotifyPayload<'a>),
Delete(DeletePayload<'a>),
VendorID(VendorIDPayload<'a>),
TSi(TrafficSelectorPayload<'a>),
TSr(TrafficSelectorPayload<'a>),
Unknown(&'a [u8]),
Dummy,
}IKE Message Payload Content
The content of an IKE message is one of the defined payloads.
Defined in RFC7296 section 3.2
This method tests for self and other values to be equal, and is used by ==. Read more
This method tests for !=.
Formats the value using the given formatter. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static