CertificatePayload

Struct CertificatePayload 

pub struct CertificatePayload<'a> {
    pub cert_encoding: CertificateEncoding,
    pub cert_data: &'a [u8],
}
Certificate Payload

The Certificate payload, denoted CERT in this document, provides a means to transport certificates or other authentication-related information via IKE. Certificate payloads SHOULD be included in an exchange if certificates are available to the sender. The Hash and URL formats of the Certificate payloads should be used in case the peer has indicated an ability to retrieve this information from elsewhere using an HTTP_CERT_LOOKUP_SUPPORTED Notify payload. Note that the term “Certificate payload” is somewhat misleading, because not all authentication mechanisms use certificates and data other than certificates may be passed in this payload.

Defined in RFC7296 section 3.6

Fields

cert_encoding: CertificateEncodingcert_data: &'a [u8]