pub struct DeletePayload<'a> {
pub protocol_id: ProtocolID,
pub spi_size: u8,
pub num_spi: u16,
pub spi: &'a [u8],
}Delete Payload
The Delete payload, denoted D in this document, contains a
protocol-specific Security Association identifier that the sender has
removed from its Security Association database and is, therefore, no
longer valid. Figure 17 shows the format of the Delete payload. It
is possible to send multiple SPIs in a Delete payload; however, each
SPI MUST be for the same protocol. Mixing of protocol identifiers
MUST NOT be performed in the Delete payload. It is permitted,
however, to include multiple Delete payloads in a single
INFORMATIONAL exchange where each Delete payload lists SPIs for a
different protocol.
Defined in RFC7296 section 3.11
This method tests for self and other values to be equal, and is used by ==. Read more
This method tests for !=.
Formats the value using the given formatter. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Mutably borrows from an owned value. Read more