IdentificationType

Struct IdentificationType 

pub struct IdentificationType(pub u8);
Type of Identification

Tuple Fields

0: u8

Implementations

Source

impl IdentificationType

pub const ID_IPV4_ADDR: IdentificationType

A single four (4) octet IPv4 address.

pub const ID_FQDN: IdentificationType

A fully-qualified domain name string. An example of an ID_FQDN is “example.com”. The string MUST NOT contain any terminators (e.g., NULL, CR, etc.). All characters in the ID_FQDN are ASCII; for an “internationalized domain name”, the syntax is as defined in [IDNA], for example “xn–tmonesimerkki-bfbb.example.net”.

pub const ID_RFC822_ADDR: IdentificationType

A fully-qualified RFC 822 email address string. An example of a ID_RFC822_ADDR is “jsmith@example.com”. The string MUST NOT contain any terminators. Because of [EAI], implementations would be wise to treat this field as UTF-8 encoded text, not as pure ASCII.

pub const ID_IPV6_ADDR: IdentificationType

A single sixteen (16) octet IPv6 address.

pub const ID_DER_ASN1_DN: IdentificationType

The binary Distinguished Encoding Rules (DER) encoding of an ASN.1 X.500 Distinguished Name.

pub const ID_DER_ASN1_GN: IdentificationType

The binary DER encoding of an ASN.1 X.509 GeneralName.

pub const ID_KEY_ID: IdentificationType

An opaque octet stream that may be used to pass vendor-specific information necessary to do certain proprietary types of identification.