NoncePayload

Struct NoncePayload 

pub struct NoncePayload<'a> {
    pub nonce_data: &'a [u8],
}
Nonce Payload

The Nonce payload, denoted as Ni and Nr in this document for the initiator’s and responder’s nonce, respectively, contains random data used to guarantee liveness during an exchange and protect against replay attacks.

Defined in RFC7296 section 3.9

Fields

nonce_data: &'a [u8]