[−][src]Struct ipsec_parser::NoncePayload
Nonce Payload
The Nonce payload, denoted as Ni and Nr in this document for the initiator's and responder's nonce, respectively, contains random data used to guarantee liveness during an exchange and protect against replay attacks.
Defined in RFC7296 section 3.9
Fields
nonce_data: &'a [u8]Trait Implementations
impl<'a> PartialEq<NoncePayload<'a>> for NoncePayload<'a>[src]
impl<'a> PartialEq<NoncePayload<'a>> for NoncePayload<'a>fn eq(&self, other: &NoncePayload<'a>) -> bool | [src] |
fn ne(&self, other: &NoncePayload<'a>) -> bool | [src] |
impl<'a> Debug for NoncePayload<'a>[src]
impl<'a> Debug for NoncePayload<'a>Auto Trait Implementations
impl<'a> Send for NoncePayload<'a>
impl<'a> Send for NoncePayload<'a>impl<'a> Sync for NoncePayload<'a>
impl<'a> Sync for NoncePayload<'a>Blanket Implementations
impl<T, U> Into for T where
U: From<T>, [src]
impl<T, U> Into for T where
U: From<T>, impl<T> From for T[src]
impl<T> From for Timpl<T, U> TryFrom for T where
T: From<U>, [src]
impl<T, U> TryFrom for T where
T: From<U>, type Error = !
🔬 This is a nightly-only experimental API. (
try_from)The type returned in the event of a conversion error.
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error> | [src] |
impl<T> Borrow for T where
T: ?Sized, [src]
impl<T> Borrow for T where
T: ?Sized, impl<T> Any for T where
T: 'static + ?Sized, [src]
impl<T> Any for T where
T: 'static + ?Sized, fn get_type_id(&self) -> TypeId | [src] |
impl<T, U> TryInto for T where
U: TryFrom<T>, [src]
impl<T, U> TryInto for T where
U: TryFrom<T>, type Error = <U as TryFrom<T>>::Error
🔬 This is a nightly-only experimental API. (
try_from)The type returned in the event of a conversion error.
fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error> | [src] |
impl<T> BorrowMut for T where
T: ?Sized, [src]
impl<T> BorrowMut for T where
T: ?Sized, fn borrow_mut(&mut self) -> &mut T | [src] |